import {select, csv, scaleLinear, max, scaleBand, axisLeft, axisBottom, format} from 'd3';

const svg = select('svg');
const circle = svg.append('circle');

var margin = {top: 50, right: 20, bottom: 20, left: 90},
    width = 960 - margin.left - margin.right,
    height = 800 - margin.top - margin.bottom;

	svg.append("g")
      .append("text")
      .attr("class", "title")
      .attr("y", margin.top)
      .attr("x", margin.left - 60)//(height-margin.bottom)/2)
      .attr("dy", ".71em")
      //.style("text-anchor", "end")
      .text("DIET");

const pieChart = (data) => {
  const size = 500;
  const fourth = size / 4;
  const half = size / 2;
  const labelOffset = fourth * 1.4;
  const total = 100;//data.reduce((acc, cur) => acc + cur.value, 0);
  const container = d3.select('svg');
  
  console.log(data);
  
  const chart = container.append('svg')
    .style('width', '100%')
    .attr('viewBox', `0 0 ${size} ${size}`);
  
  const plotArea = chart.append('g')
    .attr('transform', `translate(${half}, ${half})`);
  
  const color = d3.scaleOrdinal()
    .domain(data.map(d => d.name))
    .range(d3.schemeCategory10);
	const pie = d3.pie()
    .sort(null)
    .value(d => d.value);
  
  const arcs = pie(data);
  
  const arc = d3.arc()
    .innerRadius(0)
    .outerRadius(fourth);
  
  const arcLabel = d3.arc()
    .innerRadius(labelOffset)
    .outerRadius(labelOffset);
  
  plotArea.selectAll('path')
    .data(arcs)
    .enter()
    .append('path')
    .attr('fill', d => color(d.data.name))
    .attr('stroke', 'white')
    .attr('d', arc);
  
  const labels = plotArea.selectAll('text')
  	
    .data(arcs)
    .enter()//.filter(function(d) { return d.data.value >= 20 })
    .append('text')
    .style('text-anchor', 'middle')
    .style('alignment-baseline', 'middle')
  	.style('font-size', d => console.log(`${Math.round(d.data.value)}`))
    .style('font-size', d => `24px`)
    .attr('transform', d => `translate(${arcLabel.centroid(d)})`)
    
  labels.append('tspan')
    .attr('y', '-0.6em')
    .attr('x', 0)
    .style('font-weight', 'bold')
    .text(d => `${d.data.name}`);
  
  labels.append('tspan')
    .attr('y', '0.6em')
    .attr('x', 0)
  	.text(d => `(${Math.round(d.data.value / total * 100)}%)`);
    //.text(d => `${d.data.value} (${Math.round(d.data.value / total * 100)}%)`);
};

csv('data2.csv').then(data => {
  pieChart(data);
});